import { OnDestroy } from "@angular/core";
import { FrontendSchemaService } from "@smallstack/common-components";
import { AjvFactory, SmallstackTypeSchema } from "@smallstack/typesystem";
import { BehaviorSubject, Observable } from "rxjs";
import { FormOptions } from "../interfaces/form-options";
import { InputWidgetValidationError } from "../interfaces/form-validation";
import * as i0 from "@angular/core";
export interface FormObjectValue {
    [key: string]: FormValue;
}
export type FormValue = boolean | number | string | undefined | FormObjectValue | any;
/**
 * A service that gets injected into every each smallstack form
 */
export declare class FormService implements OnDestroy {
    #private;
    private schemaService;
    private ajvFactory;
    schema$: Observable<SmallstackTypeSchema>;
    /** Returns an observable for the current value. Only emits on changes */
    value$: Observable<any>;
    /** Returns an observable for the current validation status */
    validationErrors$: Observable<{
        [path: string]: InputWidgetValidationError[];
    }>;
    validatedFields$: Observable<string[]>;
    globalFormOptions$: BehaviorSubject<FormOptions>;
    isValid$: Observable<boolean>;
    submit$: BehaviorSubject<void>;
    hiddenFields$: Observable<string[]>;
    constructor(schemaService: FrontendSchemaService, ajvFactory: AjvFactory);
    ngOnDestroy(): void;
    /** Submits the form */
    submit(): void;
    setGlobalOption(key: keyof FormOptions, value: any): void;
    /** Returns an observable of the current validation status for the given path */
    getValidationStatusForPath$(path: string): Observable<InputWidgetValidationError[]>;
    hasBeenValidated(path: string): boolean;
    hasBeenValidated$(path: string): Observable<boolean>;
    /** Returns an immutable snapshot of the current value */
    getValue(): FormValue;
    /** Returns a snapshot of a specific path of the current value */
    getValueByPath(path: string): FormValue;
    /** Returns an observable for a specific path of the current value. Only emits on changes */
    getValueByPath$(path: string): Observable<FormValue>;
    setValue(value: FormValue): void;
    /**
     * Sets a form value by path
     * @param path The path of the value, supports dot notation (e.g. "address.street"). Leave empty to replace the root value
     * @param value The value you want to set.
     */
    setValueByPath(path: string, value: FormValue): void;
    /** Returns the schema for the given path. Supports dot notation and `array.0` qualifiers */
    getSchemaForPath$(path: string): Observable<SmallstackTypeSchema>;
    /** Returns a snapshot of the current schema */
    getSchema(): SmallstackTypeSchema;
    setSchema(schema: SmallstackTypeSchema): void;
    isRequired(path: string): boolean;
    validateAllFields(): Promise<void>;
    validateByPath(path: string): Promise<void>;
    /**
     * @returns a schema for the given form group code. If code is omitted, the properties without any group will be returned
     */
    getFormGroup(code?: string): Observable<SmallstackTypeSchema>;
    getFormGroups(): Observable<string[]>;
    private getSchemaPathFromAjvError;
    private getValidationErrors;
    /**
     * This function evaluates all if then else constructs starting from the given path downwards the tree.
     * The direction "downwards" is very important for arrays that might show up in the middle of the tree.
     * So, this function can return different schemas for the same array for different indexes.
     * */
    evalIfThenElse(fullSchema: SmallstackTypeSchema, data: any, currentPath: string): Promise<SmallstackTypeSchema>;
    evalIfThenElseProperty(schema: SmallstackTypeSchema, data: any): SmallstackTypeSchema;
    evalIfThenSchema(schema: SmallstackTypeSchema, targetSchema: SmallstackTypeSchema, data: any): SmallstackTypeSchema;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FormService>;
}
